@@ -1,14 +1,15 @@
 from PIL import Image
 
-def image_to_ascii_art(imgpath,output_file="pywhatkit_asciiart.txt"):
-    """Converts the given image to ascii art and save it to uotput_file"""
+
+def image_to_ascii_art(imgpath: str, output_file: str = "pywhatkit_asciiart.txt") -> str:
+    """Converts the given image to ascii art and save it to output_file"""
     # pass the image as command line argument
     image_path = imgpath
     img = Image.open(image_path)
 
     # resize the image
     width, height = img.size
-    aspect_ratio = height/width
+    aspect_ratio = height / width
     new_width = 80
     new_height = aspect_ratio * new_width * 0.55
     img = img.resize((new_width, int(new_height)))
@@ -21,8 +22,8 @@ def image_to_ascii_art(imgpath,output_file="pywhatkit_asciiart.txt"):
     pixels = img.getdata()
 
     # replace each pixel with a character from array
-    chars = ["*","S","#","&","@","$","%","*","!",":","."]
-    new_pixels = [chars[pixel//25] for pixel in pixels]
+    chars = ["*", "S", "#", "&", "@", "$", "%", "*", "!", ":", "."]
+    new_pixels = [chars[pixel // 25] for pixel in pixels]
     new_pixels = ''.join(new_pixels)
 
     # split string of chars into multiple strings of length equal to new width and create a list
