@@ -2,20 +2,26 @@ import webbrowser as web
 
 baseurl = "https://pywhatkit.herokuapp.com/#"
 
-def sendwhatmsg():
+
+def sendwhatmsg() -> None:
     web.open(f"{baseurl}sendwhatmsg")
 
-def playonyt():
+
+def playonyt() -> None:
     web.open(f"{baseurl}playonyt")
 
-def search():
+
+def search() -> None:
     web.open(f"{baseurl}search")
 
-def info():
+
+def info() -> None:
     web.open(f"{baseurl}info")
 
-def image_to_ascii_art():
+
+def image_to_ascii_art() -> None:
     web.open(f"{baseurl}asciiart")
 
-def text_to_handwriting():
+
+def text_to_handwriting() -> None:
     web.open(f"{baseurl}handwriting")
