@@ -1,14 +1,18 @@
 import webbrowser as web
 
-def watch_tutorial_in_Hindi():
+
+def tutorial_hindi() -> None:
     """Watch tutorial on how to use this library on YouTube in Hindi"""
     web.open("https://youtu.be/Fy7hmZ_YDjQ")
-    #Previously, it was this video https://www.youtube.com/watch?v=3hUi0qfrWWo&t=3s
-    
-def watch_tutorial_in_English():
+
+    # Previously, it was this video https://www.youtube.com/watch?v=3hUi0qfrWWo&t=3s
+
+
+def tutorial_english() -> None:
     """Watch tutorial on how to use this library on YouTube in English"""
     web.open("https://youtu.be/nAjbapi4Qk8")
 
-def developer_contact():
+
+def developer_contact() -> None:
     """Contact information of developer for feedbacks"""
     print("Message me on Telegram, username - Tag_kiya_kya\nOr email me at ankitrajjitendra816@gmail.com.")
